<?php /** @noinspection PhpUnused */

/**
 * @file
 * Contains a button action to run a modules' size retrieval
 */

declare (strict_types=1);

namespace Drupal\enviromage\Form;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\HtmlCommand;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Renderer;
use Drupal\enviromage\GetModulesSize;
use Drupal\enviromage\Utility;
use Symfony\Component\DependencyInjection\ContainerInterface;

class GetModulesSizeForm extends FormBase {

  /**
   * The renderer service.
   *
   * @var object \Drupal\Core\Render\Renderer
   */
  protected object $renderer;

  /**
   * @var object \Drupal\enviromage\GetModulesSize
   */
  protected object $GetModulesSize;

  /**
   * @var object \Drupal\enviromage\Utility
   */
  protected object $utility;

  public function __construct(
    Renderer $renderer,
    GetModulesSize $GetModulesSize,
    Utility $utility
  ) {
    $this->renderer = $renderer;
    $this->GetModulesSize = $GetModulesSize;
    $this->utility= $utility;
  }

  /** @noinspection PhpParamsInspection */
  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('renderer'),
      $container->get('enviromage.get_modules_size'),
      $container->get('enviromage.utility'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'run_functions';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['message'] = [
      '#type' => 'markup',
      '#markup' => '<p>Here you can check the memory size of your enabled
                    modules.</p>
                    <div id="result-message-modules"></div>',
    ];

    $form['actions']['#type'] = 'actions';

    $form['actions']['size_of_modules'] = [
      '#type' => 'button',
      '#value' => $this->t('Get Modules\' Size'),
      '#ajax' => [
        'callback' => '::getModulesSize',
      ],
    ];

    return $form;
  }

  public function getModulesSize(): AjaxResponse{
    $result = $this->GetModulesSize->getModulesSize();
    $modules_size = $this->utility->human_filesize($result[0]['total_size']);
    $each_module = $result[1];

    try {
      foreach ($each_module as $module_name => $memory_size) {
        $query = \Drupal::database()->insert('enviromage_msize');
        $query->fields([
          'module_name',
          'memory_size',
        ]);
        $query->values([
          $module_name,
          $this->utility->return_bytes($memory_size),
        ]);
        $query->execute();
      }

      \Drupal::messenger()->addMessage(t('Your Modules Size retrieval was logged!'));
    } catch (\Exception) {
      \Drupal::messenger()->addError(t('Sorry! We could not store this into Database!'));
    }


    $markup = [
      '#theme' => 'modules_size',
      '#modules_size' => $modules_size,
      '#each_module' => $each_module,
    ];
    $response = new AjaxResponse();

    try {
      $markup = $this->renderer->render($markup);
    } catch (\Exception) {
      $markup = "An error has happened: Try another time!";
    }

    $response->addCommand(
      new HtmlCommand(
        '#result-message-modules',
        $markup,
      )
    );
    return $response;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
  }
}
