<?php

/**
 * @file
 * Contains Drupal\environmage\GetModulesSize
 * This class provides functions that helps us calculate modules' size in disk
 * (Modules that have an update in the next release, I hope)
 */

declare(strict_types=1);

namespace Drupal\enviromage;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;


class GetModulesSize extends ControllerBase {

  /**
   * @var object \Drupal\enviromage\Utility
   */
  protected object $utility;

  public function __construct(Utility $utility) {
    $this->utility = $utility;
  }

  /** @noinspection PhpParamsInspection */
  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('enviromage.utility'),
    );
  }

  /**
   * @return array
   *   an array that contains the total size of all modules in bytes
   *   and the size of each module in a human-readable format
   */
  public function getModulesSize(): array {
    $list_of_modules1 = \Drupal::service('module_handler')
      ->getModuleDirectories();

    $list_of_modules2 = $this
      ->config('enviromage.settings')
      ->get('modules_list');

    $list_of_modules = [];
    foreach ($list_of_modules1 as $module_name => $path) {
      if ( in_array($module_name, $list_of_modules2)) {
        $list_of_modules[$module_name] = $path;
      }
    }

    $array = [0 => ['total_size' => 0],
      1 => []];
    foreach ($list_of_modules as $module_name => $path) {
      $module_size = $this->utility->getDirectorySize($path);
      $array[1][$module_name] = $this->utility->human_filesize($module_size);
      $array[0]['total_size'] += $module_size;
    }

    return $array;
  }

  /**
   * @todo try to make this function work properly
   */
  private function is_module_has_update(string $module): bool {
//    Get the current version of the module.
//    $current_version = \Drupal::service('module_handler')
//      ->moduleExists($module) ? \Drupal::service('module_handler')
//      ->getModuleInfoBykey($module)->version : FALSE;
    $current_version = 0;
    // Get the latest version of the module from the update feed.
    $latest_version = \Drupal::service('update.fetcher')
      ->fetchLatestVersion($module);

    // Check if the current version is less than the latest version.
    return $current_version < $latest_version;
  }
}
